import os
import json
import sys
import argparse

from pytvpaint import george
from pytvpaint.project import Project

project = Project.current_project()
clip = project.current_clip

def process_remaining_args(args):
    parser = argparse.ArgumentParser(description="TVPaint Update Arguments")
    parser.add_argument("--layoutbg-path", dest="layoutbg_path")
    parser.add_argument("--colorbg-path", dest="colorbg_path")
    values, _ = parser.parse_known_args(args)

    return (values.layoutbg_path, values.colorbg_path)

LAYOUTBG_PATH, COLORBG_PATH = process_remaining_args(sys.argv)

print(LAYOUTBG_PATH)
print(COLORBG_PATH)

if LAYOUTBG_PATH != 'None':

    print("[SCENE UPDATE] Updating Layout layers")

    clip.get_layer_color(by_index=6).select_layers(True)
    project_layers = clip.selected_layers

    folder_content = os.listdir(LAYOUTBG_PATH)
    folder_name = os.path.split(LAYOUTBG_PATH)[1]

    for file in folder_content:
        file_path = os.path.join(LAYOUTBG_PATH, file)
        if os.path.splitext(file_path)[1] == ".json":
            with open(file_path) as f:
                data = json.load(f)
                layers = data["layers"]
                hidden_layers = data["hidden_layers"]
            break
    
    #remove layers not in new list
    for pl in project_layers:
        pln = pl.name.replace("OL & UL_","")
        if pln not in layers:
            pl.remove()

    #replace layers with new list
    for l in layers:
        file = folder_name + "-" + l.replace(" ", "-") + ".png"
        file_path = os.path.join(LAYOUTBG_PATH, file)

        if os.path.exists(file_path):
            layer_name ="OL & UL_"+l
            
            layer = clip.get_layer(by_name=layer_name)
            if not layer:
                layer = clip.add_layer(layer_name)
                layer.color = clip.get_layer_color(by_index=6)
            
            layer.load_image(file_path, frame=0)

            if l in hidden_layers:
                layer.opacity = 0

project.save_video_dependencies()
project.save_audio_dependencies()
print("[SCENE UPDATE] Save project")
project.save()

print("[SCENE UPDATE] Update complete")
project.close_all(True)

